==> material-ui-shell-1.1.17.tgz: package/es/containers/ResponsiveMenu/ResponsiveMenu.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import PropTypes from 'prop-types';
import React from 'react';
import SwipeableDrawer from '@material-ui/core/SwipeableDrawer';
import clsx from 'clsx';
import { makeStyles, useTheme } from '@material-ui/core/styles';
import { useMenu } from 'material-ui-shell/lib/providers/Menu';
var drawerWidth = 240;
var iOS = process.browser && /iPad|iPhone|iPod/.test(navigator.userAgent);
var useStyles = makeStyles(function (theme) {
  return {
    toolbar: _extends({
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end',
      padding: '0 8px'
    }, theme.mixins.toolbar),
    drawerPaper: {
      height: '100vh',
      width: drawerWidth,
      [theme.breakpoints.up('md')]: {
        position: 'relative'
      },
      transition: theme.transitions.create('width', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    drawerPaperOpen: {
      height: '100vh',
      position: 'relative',
      whiteSpace: 'nowrap',
      width: drawerWidth,
      transition: theme.transitions.create('width', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    drawerPaperClose: {
      height: '100vh',
      overflowX: 'hidden',
      transition: theme.transitions.create('width', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen
      }),
      width: theme.spacing(1) * 7,
      [theme.breakpoints.up('sm')]: {
        width: theme.spacing(1) * 9
      }
    },
    hide: {
      display: 'none'
    }
  };
});

var ResponsiveMenu = function ResponsiveMenu(_ref) {
  var children = _ref.children,
      width = _ref.width;
  var classes = useStyles();
  var theme = useTheme();

  var _useMenu = useMenu(),
      isDesktop = _useMenu.isDesktop,
      isDesktopOpen = _useMenu.isDesktopOpen,
      isMobileOpen = _useMenu.isMobileOpen,
      isMini = _useMenu.isMini,
      setMobileOpen = _useMenu.setMobileOpen;

  var handleDrawerToggle = function handleDrawerToggle() {
    setMobileOpen(!isMobileOpen);
  };

  return /*#__PURE__*/React.createElement("div", {
    style: {
      boxSizing: 'content-box'
    }
  }, /*#__PURE__*/React.createElement(SwipeableDrawer, {
    disableBackdropTransition: !iOS,
    disableDiscovery: iOS,
    variant: isDesktop ? 'permanent' : 'temporary' // className={classes.drawer}
    ,
    onClose: handleDrawerToggle,
    anchor: !isDesktop ? undefined : theme.direction === 'rtl' ? 'right' : 'left',
    classes: {
      paper: isDesktop ? clsx(classes.drawerPaperOpen, !isDesktopOpen && classes.drawerPaperClose, !isMini && !isDesktopOpen && classes.hide) : classes.drawerPaper
    },
    open: isDesktop ? isDesktopOpen : isMobileOpen,
    onOpen: handleDrawerToggle,
    ModalProps: {
      keepMounted: true // Better open performance on mobile.

    }
  }, children));
};

ResponsiveMenu.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.any
} : {};
export default ResponsiveMenu;

==> material-ui-shell-1.1.27.tgz: package/es/containers/ResponsiveMenu/ResponsiveMenu.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import PropTypes from 'prop-types';
import React from 'react';
import SwipeableDrawer from '@material-ui/core/SwipeableDrawer';
import clsx from 'clsx';
import { makeStyles, useTheme } from '@material-ui/core/styles';
import { useMenu } from 'material-ui-shell/lib/providers/Menu';
var drawerWidth = 240;
var iOS = process.browser && /iPad|iPhone|iPod/.test(navigator.userAgent);
var useStyles = makeStyles(function (theme) {
  return {
    toolbar: _extends({
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end',
      padding: '0 8px'
    }, theme.mixins.toolbar),
    drawerPaper: {
      height: '100vh',
      width: drawerWidth,
      [theme.breakpoints.up('md')]: {
        position: 'relative'
      },
      transition: theme.transitions.create('width', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    drawerPaperOpen: {
      height: '100vh',
      position: 'relative',
      whiteSpace: 'nowrap',
      width: drawerWidth,
      transition: theme.transitions.create('width', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    drawerPaperClose: {
      height: '100vh',
      overflowX: 'hidden',
      transition: theme.transitions.create('width', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen
      }),
      width: theme.spacing(1) * 7,
      [theme.breakpoints.up('sm')]: {
        width: theme.spacing(1) * 9
      }
    },
    hide: {
      display: 'none'
    }
  };
});

var ResponsiveMenu = function ResponsiveMenu(_ref) {
  var children = _ref.children,
      width = _ref.width;
  var classes = useStyles();
  var theme = useTheme();

  var _useMenu = useMenu(),
      dispatch = _useMenu.dispatch,
      menuStore = _useMenu.menuStore,
      isDesktop = _useMenu.isDesktop,
      isMiniMode = _useMenu.isMiniMode,
      isMenuOpen = _useMenu.isMenuOpen,
      isMobileMenuOpen = _useMenu.isMobileMenuOpen,
      setMobileMenuOpen = _useMenu.setMobileMenuOpen;

  var handleDrawerToggle = function handleDrawerToggle() {
    setMobileMenuOpen(!isMobileMenuOpen);
  };

  return /*#__PURE__*/React.createElement("div", {
    style: {
      boxSizing: 'content-box'
    }
  }, /*#__PURE__*/React.createElement(SwipeableDrawer, {
    disableBackdropTransition: !iOS,
    disableDiscovery: iOS,
    variant: isDesktop ? 'permanent' : 'temporary',
    onClose: handleDrawerToggle,
    anchor: !isDesktop ? undefined : theme.direction === 'rtl' ? 'right' : 'left',
    classes: {
      paper: isDesktop ? clsx(classes.drawerPaperOpen, !isMenuOpen && classes.drawerPaperClose, !isMiniMode && !isMenuOpen && classes.hide) : classes.drawerPaper
    },
    open: isDesktop ? isMenuOpen : isMobileMenuOpen,
    onOpen: handleDrawerToggle,
    ModalProps: {
      keepMounted: true // Better open performance on mobile.

    }
  }, children));
};

ResponsiveMenu.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.any
} : {};
export default ResponsiveMenu;
